# DATA

This repository contains the input files for IFS-NEMO for the following resolutions:

- tco79/eORCA1
- tco399/eORCA025
- tco1279/eORCA12
- tco2559/eORCA12

The input files comprise the initial conditions, forcing, and auxiliary files. Additinoally, the model configurations are provided as fortran namelists:

IFS: \<ATM-RESOL\>/\<expid\>/LWDA/\<startdate\>/gfc/fort.4  
WAM: \<ATM-RESOL\>/\<expid\>/LWDA/\<startdate\>/gfc/wam_namelist  
NEMOCOUP: \<ATM-RESOL\>/\<expid\>/LWDA/\<startdate\>/gfc/namnemocoup.in  
NEMO-OCE nemo/V40/\<OCE-RESOL\>/\<startdate\>/namelist_cfg  
NEMO-ICE nemo/V40/\<OCE-RESOL\>/\<startdate\>/namelist_ice_cfg  

## Nemo

### Namelists

- eORCA12_Z75: 
  - 1988010100/1990010100:
    - Phase 2 namelists defined by ECMWF in RAPS (pending PR 28/11/2024): https://git.ecmwf.int/projects/DE/repos/raps/pull-requests/178/overview
- eORCA025_Z75: 
  - 1988010100/1990010100:
    - Phase 2 namelists defined by ECMWF in RAPS (pending PR 28/11/2024): https://git.ecmwf.int/projects/DE/repos/raps/pull-requests/178/overview
- eORCA1_Z75: 
  - 1990010100:
    - Phase 1 namelists with ln_ssr disabled (TODO: need revision)

### Initial conditions

The NEMO initial conditions are seperated by resolution. The 1988 initial conditions are based on ocean only spinups and the 1990 initial conditions on coupled spinups.

- eORCA12_Z75: 
  - 1988010100 (symbolic link from igza, which is an ocean only spinup):
    - ocean restarts 1988 from an ocean spinup provided by ECMWF using phase 2 namelists (28/11/2024):
      - 'igza_19900101_000000_restart_ice.nc'
      - 'igza_19900101_000000_restart.nc'
- eORCA025_Z75: 
  - 1990010100:
    - ocean spinup restarts:
      - 'a15s_19900101_000000_restart_ice_out.nc'
      - 'a15s_19900101_000000_restart_out.nc'
    - ocean spinup namelists:
      - nemo/V40/eORCA025_Z75/a15s/namelist_cfg.a15s
      - nemo/V40/eORCA025_Z75/a15s/namelist_ice_cfg.a15s
      - nemo/V40/eORCA025_Z75/a15s/namelist_ice_ref.a15s
      - nemo/V40/eORCA025_Z75/a15s/namelist_ref.a15s
- eORCA1_Z75: 
  - 1990010100:
    - unclear

## IFS

### Initial conditions

- Tco1279l137:
  - hz9o - 1988010100 and 1990010100 use the same atmospheric initial conditions, generated from 2020 
  - the 2020 atmospheric initial conditinos are provided by ECMWF

- Tco2559l137:
  - hzfy - 1988010100, 1990010100, and 2020010100 use the same atmospheric initial conditions, generated from 2020 
  - the 2020 atmospheric initial conditinos are provided by ECMWF 
  - Initial conditions for 1990 for E and O-suite are given in form of restart files from the coupled spinup (a27r)
    - https://earth.bsc.es/gitlab/digital-twins/de_340-2/simulation-runs/-/issues/55
    - path in repository: `restarts/tco2559l137.eORCA12_Z75/a27r/25`


- Tco399l137:
  - hz9n - 1988010100 and 1990010100 use the same atmospheric initial conditions, generated from 2020 
  - the 2020 atmospheric initial conditinos are provided by ECMWF


- Tco79l137:
  - hz9m - 1990010100 use the same atmospheric initial conditions, generated from 2020 
  - the 2020 atmospheric initial conditinos are provided by ECMWF


- All resolutions:
  - additionally, we copied the aerosol files from '/pfs/lustrep3/scratch/project_465000454/bjimenez/inputs_bjimenez/inputs_ifs_c48r1/ifsdata/cmip6-ozone' and the file 'Aerosols_1950_2015.nc' from '/pfs/lustrep3/scratch/project_465000454/bjimenez/inputs_bjimenez/inputs_ifs_c48r1/ifsdata', and renamed it to 'aerosols_CONFESS_1950_2015.nc' to make it compatible with the model script. 
  - Phase 2 namelists defined by ECMWF in RAPS (pending PR 28/11/2024): https://git.ecmwf.int/projects/DE/repos/raps/pull-requests/178/overview

### Over land climatologies for IFS (ICMCL) 
- \<ATM-RESOL\>/ifsINIT
- years 2020 and 2021 are provided by ECMWF. Other years are generated from those years, only with updated dates.


# comments

- ocean spinup has been generated using TEOS10, seaice fractional coupling and nn_flxdst=-1, although this latest one has been confirmed to have no effect in forced run.
- Current modification of the nemo seaice namelists to consider nn_flxdist as -1


# experiment execution using RAPS

The complete hres command for the tco2559/eORCA12 experiments is: 

```
hres -p 2080 -t 14 -h 1 -j 16100051 -J a27r_19880101_fc0_24_SIM -d 1988010100 -e hzfy -L LWDA -T tco -r 2559 -l 137 -f d731 -x '' -N 32 -H mn5-gpp -n 260 -C intel --ifs-bundle-build-dir=/gpfs/projects/ehpc01/models/ifs-nemo/dev-marc/DE_CY48R1.0_climateDT_20250212/make/marenostrum5-intel/build --icmcl ICMCL_2559_198912 -R --nemo --nemo-ver=V40 --nemo-grid=eORCA12_Z75 --nemo-xproc=-1 --nemo-yproc=-1 --deep --nonemopart --restartdirectory=/gpfs/scratch/ehpc01/bsc998159/a27r/restarts/fc0/current --realization=1 --keeprestart --experiment=control --cbmf_reduced --teos10 --inproot-namelists --fixyear=1990 --ifs-and-wam-multio --no-ozone --sicoupl=1 --hugepages --nemorwdist --preload-mir-cache nemodistdir=/gpfs/scratch/ehpc01/bsc032799/a1u1/rundir/tco2559l137/a1u1/hres/parinter_eORCA12_Z75_1984_-1x-1/ --keepfdb --multio-production-fdbs=/gpfs/scratch/ehpc01/experiments/a27r/fdb/native:/gpfs/scratch/ehpc01/experiments/a27r/fdb:/gpfs/scratch/ehpc01/experiments/a27r/fdb/latlon --outexp=a27r --keepnetcdf --nextgemsout=6 --wam-multio --ifs-multio --io-nodes=8 --io-ppn=16 --nemo-multio-server-nodes=4 --nemo-multio-server-ppn=8
```

# How to use the repository
1. clone the repository  
```
git clone -b experiment/ClimateDT-phase2 https://earth.bsc.es/gitlab/kkeller/dvc-cache-de340.git \<path\>
```  
2. Get the data from dvc  
```
dvc checkout
```
